@@ -1,10 +1,10 @@
 /*
  *
- * $Id: k3bcore.h 516308 2006-03-06 16:32:28Z trueg $
+ * $Id: k3bcore.h 689512 2007-07-18 12:59:50Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,12 +18,12 @@
 #define _K3B_CORE_H_
 
 #include <qobject.h>
-#include <qptrlist.h>
+#include <qvaluelist.h>
+
+#include "k3b_export.h"
 
 
-
-
-#define LIBK3B_VERSION "0.12.14"
+#define LIBK3B_VERSION "1.0.3"
 
 #define k3bcore K3bCore::k3bCore()
 
@@ -33,12 +33,15 @@ class K3bVersion;
 class KConfig;
 class KAboutData;
 class K3bJob;
+class K3bBurnJob;
 class K3bGlobalSettings;
 class K3bPluginManager;
+class QCustomEvent;
 
 
 namespace K3bDevice {
   class DeviceManager;
+  class Device;
 }
 
 
@@ -49,7 +52,7 @@ namespace K3bDevice {
  * This is the heart of the K3b system. Every plugin may use this
  * to get the information it needs.
  */
-class K3bCore : public QObject
+class LIBK3B_EXPORT K3bCore : public QObject
 {
   Q_OBJECT
 
@@ -61,7 +64,7 @@ class K3bCore : public QObject
   K3bCore( QObject* parent = 0, const char* name = 0 );
   virtual ~K3bCore();
 
-  const QPtrList<K3bJob>& runningJobs() const;
+  const QValueList<K3bJob*>& runningJobs() const;
 
   /**
    * Equals to !runningJobs().isEmpty()
@@ -69,7 +72,8 @@ class K3bCore : public QObject
   bool jobsRunning() const;
 
   /**
-   * The default implementation scans for devices, applications, and reads the global settings.
+   * The default implementation calls add four initXXX() methods,
+   * scans for devices, applications, and reads the global settings.
    */
   virtual void init();
 
@@ -83,7 +87,11 @@ class K3bCore : public QObject
    */
   virtual void saveSettings( KConfig* c = 0 );
 
-  K3bDevice::DeviceManager* deviceManager() const;
+  /**
+   * If this is reimplemented it is recommended to also reimplement
+   * init().
+   */
+  virtual K3bDevice::DeviceManager* deviceManager() const;
 
   /**
    * Returns the external bin manager from K3bCore.
@@ -114,8 +122,29 @@ class K3bCore : public QObject
    */
   virtual KConfig* config() const;
 
+  /**
+   * Used by the writing jobs to block a device.
+   * This makes sure no device is used twice within libk3b
+   *
+   * When using this method in a job be aware that reimplementations might
+   * open dialogs and resulting in a blocking call.
+   *
+   * This method calls internalBlockDevice() to do the actual work.
+   */
+  bool blockDevice( K3bDevice::Device* );
+  void unblockDevice( K3bDevice::Device* );
+
   static K3bCore* k3bCore() { return s_k3bCore; }
 
+ signals:
+  /**
+   * Emitted once a new job has been started. This includes burn jobs.
+   */
+  void jobStarted( K3bJob* );
+  void burnJobStarted( K3bBurnJob* );
+  void jobFinished( K3bJob* );
+  void burnJobFinished( K3bBurnJob* );
+
  public slots:
   /**
    * Every running job registers itself with the core.
@@ -125,6 +154,23 @@ class K3bCore : public QObject
   void registerJob( K3bJob* job );
   void unregisterJob( K3bJob* job );
 
+ protected:
+  /**
+   * Reimplement this to add additonal checks.
+   *
+   * This method is thread safe. blockDevice makes sure
+   * it is only executed in the GUI thread.
+   */
+  virtual bool internalBlockDevice( K3bDevice::Device* );
+  virtual void internalUnblockDevice( K3bDevice::Device* );
+
+  virtual void initGlobalSettings();
+  virtual void initExternalBinManager();
+  virtual void initDeviceManager();
+  virtual void initPluginManager();
+
+  virtual void customEvent( QCustomEvent* e );
+
  private:
   class Private;
   Private* d;
